@@ -2,7 +2,7 @@
 
 __author__ = """Andres Kepler"""
 __email__ = 'andres.kepler@fleetcomplete.com'
-__version__ = '0.1.10'
+__version__ = '0.1.11'
 
 import datetime
 
@@ -149,6 +149,8 @@ def parse_file(args):
                           )
         if serial not in serial_collector:
             serial_collector.append(serial)
-            logging.info({"terminal_serial": payload.terminal_serial}, extra=payload.__dict__())
+            payload_d = payload.__dict__()
+            payload_d['type'] = "driver-parser"
+            logging.info({"terminal_serial": payload.terminal_serial}, extra=payload_d)
     logging.debug("Stop")
     return 0
